"""
Application-class that implements pyFoamClearCase.py
"""

from PyFoamApplication import PyFoamApplication

from PyFoam.RunDictionary.SolutionDirectory import SolutionDirectory

class ClearCase(PyFoamApplication):
    def __init__(self):
        description="""
Removes all timesteps but the first from a case-directory.
Also removes other data that is generated by sovers/utilities/PyFoam
"""
        PyFoamApplication.__init__(self,description=description,usage="%prog <caseDirectory>",interspersed=True,nr=1)

    def addOptions(self):
        self.parser.add_option("--after",
                         type="float",
                         dest="after",
                         default=None,
                         help="Only remove timesteps after this time")
        self.parser.add_option("--no-processor",
                         action="store_false",
                         dest="processor",
                         default=True,
                         help="Keep the processor directories")
        self.parser.add_option("--no-pyfoam",
                         action="store_false",
                         dest="pyfoam",
                         default=True,
                         help="Keep the PyFoam-specific directories and logfiles")

    def run(self):
        cName=self.parser.getArgs()[0]
        
        sol=SolutionDirectory(cName)
        sol.clear(after=self.parser.getOptions().after,
                  processor=self.parser.getOptions().processor,
                  pyfoam=self.parser.getOptions().pyfoam)
        
