#  ICE Revision: $Id: LogLineAnalyzer.py 7581 2007-06-27 15:29:14Z bgschaid $ 
"""Base class for analyzing lines"""

class LogLineAnalyzer(object):
    """Base class for the analysis of all lines from a OpenFOAM-log

    Lines are available one at a time"""
    
    def __init__(self):
        self.parent=None

    def doAnalysis(self,line):
        """Analyze a line

        line - the line to be analyzed

        This method carries the main functionality in the sub-classes"""
        pass

    def timeChanged(self):
        """The value of the time has changed in the Log-file
        
        For subclasses that need to know the current time"""
        pass
    
    def setParent(self,parent):
        """Introduces the LineAnalyzer to its supervisor

        @param parent: The Analyzer class of which this is a part"""
        self.parent=parent

    def setDirectory(self,oDir):
        """Set the directory to which output is to be written (if any
        output is written)"""
        pass
    
    def goOn(self):
        """If the analyzer thinks the simulation should be stopped
        (for instance because of convergence) it returns false"""
        return True

    def getTime(self):
        """@returns: current time"""
        return self.parent.getTime()
